Enum EthBroadcastMessage
pub enum EthBroadcastMessage<N = BasicNetworkPrimitives<EthPrimitives, EthereumTxEnvelope<TxEip4844WithSidecar>>>where
N: NetworkPrimitives,{
NewBlock(Arc<<N as NetworkPrimitives>::NewBlockPayload>),
Transactions(SharedTransactions<<N as NetworkPrimitives>::BroadcastedTransaction>),
BroadcastPoolTransactions(BroadcastPoolTransactions),
}Expand description
Represents broadcast messages of EthMessage with the same object that can be sent to
multiple peers.
Messages that contain a list of hashes depend on the peer the message is sent to. A peer should never receive a hash of an object (block, transaction) it has already seen.
Note: This is only useful for outgoing messages.
Variants
NewBlock(Arc<<N as NetworkPrimitives>::NewBlockPayload>)
Represents a new block broadcast message.
Transactions(SharedTransactions<<N as NetworkPrimitives>::BroadcastedTransaction>)
Represents a transactions broadcast message.
BroadcastPoolTransactions(BroadcastPoolTransactions)
Represents cached outbound pool transactions broadcast message.
Implementations
impl<N> EthBroadcastMessage<N>where
N: NetworkPrimitives,
impl<N> EthBroadcastMessage<N>where
N: NetworkPrimitives,
pub const fn message_id(&self) -> EthMessageID
pub const fn message_id(&self) -> EthMessageID
Returns the message’s ID.
pub fn encoded(self) -> Bytes
pub fn encoded(self) -> Bytes
Encodes this broadcast to its id-prefixed RLPx message bytes.