pub struct ProtocolIngressLimits { /* private fields */ }Expand description
Local limits for inbound messages of an RLPx subprotocol.
These limits are not advertised to the remote peer and do not affect message ID negotiation.
Implementations
Sourceimpl ProtocolIngressLimits
impl ProtocolIngressLimits
Sourcepub const DEFAULT_MAX_BUFFERED_BYTES: usize
pub const DEFAULT_MAX_BUFFERED_BYTES: usize
Default byte budget for messages waiting to be polled by a protocol connection.
Sourcepub const DEFAULT_MAX_BUFFERED_MESSAGES: usize = 1024
pub const DEFAULT_MAX_BUFFERED_MESSAGES: usize = 1024
Default message budget for messages waiting to be polled by a protocol connection.
Sourcepub const fn new(max_frame_bytes: usize) -> Self
pub const fn new(max_frame_bytes: usize) -> Self
Creates limits with an explicit maximum inbound frame size.
The frame size includes the capability-local message ID byte.
Panics
Panics if max_frame_bytes is zero.
Sourcepub const fn with_max_buffered_bytes(self, max_buffered_bytes: usize) -> Self
pub const fn with_max_buffered_bytes(self, max_buffered_bytes: usize) -> Self
Sourcepub const fn with_max_buffered_messages(
self,
max_buffered_messages: usize,
) -> Self
pub const fn with_max_buffered_messages( self, max_buffered_messages: usize, ) -> Self
Sourcepub const fn max_frame_bytes(&self) -> Option<usize>
pub const fn max_frame_bytes(&self) -> Option<usize>
Returns the explicit maximum inbound frame size, if configured.
Sourcepub const fn max_buffered_bytes(&self) -> usize
pub const fn max_buffered_bytes(&self) -> usize
Returns the maximum number of buffered frame bytes.
Sourcepub const fn max_buffered_messages(&self) -> usize
pub const fn max_buffered_messages(&self) -> usize
Returns the maximum number of buffered messages.