Struct NewPooledTransactionHashes72
pub struct NewPooledTransactionHashes72 {
pub types: Vec<u8>,
pub sizes: Vec<usize>,
pub hashes: Vec<FixedBytes<32>>,
pub cell_mask: Option<FixedBytes<16>>,
}Expand description
Same as NewPooledTransactionHashes68 but adds cell mask of B128.
Fields
types: Vec<u8>Transaction types for new transactions that have appeared on the network.
Note on RLP encoding and decoding
In the eth/72 spec this is defined the following way:
[types: B, [size_0: P, size_1: P, ...], [hash_0: B_32, hash_1: B_32, ...], cell_mask: B_16]
sizes: Vec<usize>Transaction sizes for new transactions that have appeared on the network.
hashes: Vec<FixedBytes<32>>Transaction hashes for new transactions that have appeared on the network.
cell_mask: Option<FixedBytes<16>>Cell mask for new transactions that have appeared on the network.
Implementations
impl NewPooledTransactionHashes72
impl NewPooledTransactionHashes72
pub fn metadata_iter(
&self,
) -> impl Iterator<Item = (&FixedBytes<32>, (u8, usize))>
pub fn metadata_iter( &self, ) -> impl Iterator<Item = (&FixedBytes<32>, (u8, usize))>
Returns an iterator over tx hashes zipped with corresponding metadata.
pub fn extend<'a, T>(&mut self, txs: impl IntoIterator<Item = &'a T>)where
T: SignedTransaction,
pub fn extend<'a, T>(&mut self, txs: impl IntoIterator<Item = &'a T>)where
T: SignedTransaction,
Appends the provided transactions
pub fn shrink_to_fit(&mut self)
pub fn shrink_to_fit(&mut self)
Shrinks the capacity of the message vectors as much as possible.
pub fn with_transaction<T>(self, tx: &T) -> NewPooledTransactionHashes72where
T: SignedTransaction,
pub fn with_transaction<T>(self, tx: &T) -> NewPooledTransactionHashes72where
T: SignedTransaction,
Consumes and appends a transaction
pub fn with_transactions<'a, T>(
self,
txs: impl IntoIterator<Item = &'a T>,
) -> NewPooledTransactionHashes72where
T: SignedTransaction,
pub fn with_transactions<'a, T>(
self,
txs: impl IntoIterator<Item = &'a T>,
) -> NewPooledTransactionHashes72where
T: SignedTransaction,
Consumes and appends the provided transactions